[Zope3-checkins] CVS: Zope3/src/zope/app/workflow - configure.zcml:1.8.4.1 definition.py:1.3.24.3 instance.py:1.7.6.3 service.py:1.9.10.2

Jim Fulton jim at zope.com
Fri Sep 12 15:16:10 EDT 2003


Update of /cvs-repository/Zope3/src/zope/app/workflow
In directory cvs.zope.org:/tmp/cvs-serv13470/src/zope/app/workflow

Modified Files:
      Tag: parentgeddon-branch
	configure.zcml definition.py instance.py service.py 
Log Message:
Can't have the tests passing, can we?

=== Zope3/src/zope/app/workflow/configure.zcml 1.8 => 1.8.4.1 ===
--- Zope3/src/zope/app/workflow/configure.zcml:1.8	Wed Aug 27 13:13:45 2003
+++ Zope3/src/zope/app/workflow/configure.zcml	Fri Sep 12 15:15:39 2003
@@ -86,7 +86,7 @@
       />
   <require
       permission="zope.ManageServices"
-      interface="zope.app.interfaces.container.IDeleteNotifiable"
+      interface="zope.app.interfaces.container.IRemoveNotifiable"
       />
 </content>
 


=== Zope3/src/zope/app/workflow/definition.py 1.3.24.2 => 1.3.24.3 ===
--- Zope3/src/zope/app/workflow/definition.py:1.3.24.2	Tue Sep  9 14:08:21 2003
+++ Zope3/src/zope/app/workflow/definition.py	Fri Sep 12 15:15:39 2003
@@ -90,7 +90,7 @@
 
     has_key = __contains__
 
-    def setObject(self, key, object):
+    def __setitem__(self, key, object):
         '''See interface IProcessDefinitionElementContainer'''
         bad = False
         if isinstance(key, StringTypes):


=== Zope3/src/zope/app/workflow/instance.py 1.7.6.2 => 1.7.6.3 ===
--- Zope3/src/zope/app/workflow/instance.py:1.7.6.2	Tue Sep  9 14:08:21 2003
+++ Zope3/src/zope/app/workflow/instance.py	Fri Sep 12 15:15:39 2003
@@ -107,7 +107,7 @@
         "See IProcessInstanceContainer"
         return self.wfdata.items()
 
-    def setObject(self, key, object):
+    def __setitem__(self, key, object):
         "See IProcessInstanceContainer"
 
         if not isinstance(key, StringTypes):


=== Zope3/src/zope/app/workflow/service.py 1.9.10.1 => 1.9.10.2 ===
--- Zope3/src/zope/app/workflow/service.py:1.9.10.1	Mon Sep  8 14:21:53 2003
+++ Zope3/src/zope/app/workflow/service.py	Fri Sep 12 15:15:39 2003
@@ -111,30 +111,28 @@
         return IProcessDefinition
 
     # The following hooks are called only if we implement
     # IAddNotifiable and IDeleteNotifiable.
 
-    def afterAddHook(self, registration, container):
+    def addNotify(self, event):
         """Hook method will call after an object is added to container.
 
         Defined in IAddNotifiable.
         """
-        super(ProcessDefinitionRegistration, self).afterAddHook(registration,
-                                                                 container)
-        pd = registration.getComponent()
+        super(ProcessDefinitionRegistration, self).addNotify(event)
+        pd = self.getComponent()
         adapter = getAdapter(pd, IRegistered)
-        adapter.addUsage(getPath(registration))
+        adapter.addUsage(getPath(self))
 
 
-    def beforeDeleteHook(self, registration, container):
+    def removeNotify(self, event):
         """Hook method will call before object is removed from container.
 
-        Defined in IDeleteNotifiable.
+        Defined in IRemoveNotifiable.
         """
-        pd = registration.getComponent()
+        pd = self.getComponent()
         adapter = getAdapter(pd, IRegistered)
-        adapter.removeUsage(getPath(registration))
-        super(ProcessDefinitionRegistration, self).beforeDeleteHook(
-            registration, container)
+        adapter.removeUsage(getPath(self))
+        super(ProcessDefinitionRegistration, self).removeNotify(event)
 
 
 class ProcessDefinitionTerm:
@@ -111,30 +111,28 @@
 
     # The following hooks are called only if we implement
-    # IAddNotifiable and IDeleteNotifiable.
+    # IAddNotifiable and IRemoveNotifiable.
 




More information about the Zope3-Checkins mailing list